==> apache-iotdb-0.11.0-source-release.zip: apache-iotdb-0.11.0/server/src/main/java/org/apache/iotdb/db/query/reader/series/SeriesRawDataPointReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.db.query.reader.series;

import java.io.IOException;
import org.apache.iotdb.tsfile.read.TimeValuePair;
import org.apache.iotdb.tsfile.read.common.BatchData;
import org.apache.iotdb.tsfile.read.reader.IPointReader;

/**
 * only for test now
 */
public class SeriesRawDataPointReader implements IPointReader {

  private final SeriesRawDataBatchReader batchReader;

  private boolean hasCachedTimeValuePair;
  private BatchData batchData;
  private TimeValuePair timeValuePair;

  public SeriesRawDataPointReader(SeriesReader seriesReader) {
    this.batchReader = new SeriesRawDataBatchReader(seriesReader);
  }


  @Override
  public boolean hasNextTimeValuePair() throws IOException {
    if (hasCachedTimeValuePair) {
      return true;
    }

    if (batchData != null && batchData.hasCurrent()) {
      timeValuePair = new TimeValuePair(batchData.currentTime(),
          batchData.currentTsPrimitiveType());
      hasCachedTimeValuePair = true;
      batchData.next();
      return true;
    }

    while (batchReader.hasNextBatch()) {
      batchData = batchReader.nextBatch();
      if (batchData.hasCurrent()) {
        timeValuePair = new TimeValuePair(batchData.currentTime(),
            batchData.currentTsPrimitiveType());
        hasCachedTimeValuePair = true;
        batchData.next();
        return true;
      }
    }

    return false;
  }

  @Override
  public TimeValuePair nextTimeValuePair() throws IOException {
    if (hasCachedTimeValuePair || hasNextTimeValuePair()) {
      hasCachedTimeValuePair = false;
      return timeValuePair;
    } else {
      throw new IOException("no next data");
    }
  }

  @Override
  public TimeValuePair currentTimeValuePair() {
    return timeValuePair;
  }

  @Override
  public void close() throws IOException {
    // no resources need to close
  }
}

==> apache-iotdb-0.13.4-source-release.zip: apache-iotdb-0.13.4/server/src/main/java/org/apache/iotdb/db/query/reader/series/SeriesRawDataPointReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.db.query.reader.series;

import org.apache.iotdb.tsfile.read.TimeValuePair;
import org.apache.iotdb.tsfile.read.common.BatchData;
import org.apache.iotdb.tsfile.read.reader.IPointReader;

import java.io.IOException;

/** only for test now */
public class SeriesRawDataPointReader implements IPointReader {

  private final SeriesRawDataBatchReader batchReader;

  private boolean hasCachedTimeValuePair;
  private BatchData batchData;
  private TimeValuePair timeValuePair;

  public SeriesRawDataPointReader(SeriesReader seriesReader) {
    this.batchReader = new SeriesRawDataBatchReader(seriesReader);
  }

  @Override
  public boolean hasNextTimeValuePair() throws IOException {
    if (hasCachedTimeValuePair) {
      return true;
    }

    if (batchData != null && batchData.hasCurrent()) {
      timeValuePair =
          new TimeValuePair(batchData.currentTime(), batchData.currentTsPrimitiveType());
      hasCachedTimeValuePair = true;
      batchData.next();
      return true;
    }

    while (batchReader.hasNextBatch()) {
      batchData = batchReader.nextBatch();
      if (batchData.hasCurrent()) {
        timeValuePair =
            new TimeValuePair(batchData.currentTime(), batchData.currentTsPrimitiveType());
        hasCachedTimeValuePair = true;
        batchData.next();
        return true;
      }
    }

    return false;
  }

  @Override
  public TimeValuePair nextTimeValuePair() throws IOException {
    if (hasCachedTimeValuePair || hasNextTimeValuePair()) {
      hasCachedTimeValuePair = false;
      return timeValuePair;
    } else {
      throw new IOException("no next data");
    }
  }

  @Override
  public TimeValuePair currentTimeValuePair() {
    return timeValuePair;
  }

  @Override
  public void close() throws IOException {
    // no resources need to close
  }
}
